@@ -2,11 +2,15 @@
 
 import asyncio
 
-from cti.api.session import get_async_client, close_async_client, initialize_async_client
+from cti.api.session import (
+    get_async_client,
+    close_async_client,
+    initialize_async_client,
+)
+
 
 async def main():
-    """Example of using the Clarity API asynchronously
-    """
+    """Example of using the Clarity API asynchronously"""
     try:
         await initialize_async_client()
         client = get_async_client()
@@ -15,5 +19,6 @@ async def main():
     finally:
         await close_async_client()
 
+
 if __name__ == "__main__":
     asyncio.run(main())
